@@ -564,9 +564,6 @@ gda_mysql_recordset_fetch_nb_rows (GdaDataSelect *model)
 	if (model->advertized_nrows >= 0)
 		return model->advertized_nrows;
 
-	/* use C API to determine number of rows,if possible */
-	// TO_IMPLEMENT;
-	
 	model->advertized_nrows = mysql_stmt_affected_rows (imodel->priv->mysql_stmt);
 	
 	return model->advertized_nrows;
@@ -633,6 +630,7 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, gint rownum, GError **error)
 		int intvalue = 0;
 		long long longlongvalue = 0;
 		double doublevalue = 0.0;
+		float floatvalue = 0.;
 		MYSQL_TIME timevalue = { 0 };
 		my_bool is_null = FALSE;
 		unsigned long length;
@@ -733,15 +731,24 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, gint rownum, GError **error)
 			}
 
 			break;
-		case MYSQL_TYPE_FLOAT:
+		case MYSQL_TYPE_FLOAT: {
+			g_memmove (&floatvalue, mysql_bind_result[i].buffer, sizeof(float));
+			
+			if (type == G_TYPE_FLOAT)
+				g_value_set_float (value, (float) floatvalue);
+			else {
+				gda_row_invalidate_value (row, value);
+				g_set_error (error, GDA_SERVER_PROVIDER_ERROR,
+					     GDA_SERVER_PROVIDER_DATA_ERROR,
+					     _("Type %s not mapped for value %f"),
+					     g_type_name (type), doublevalue);
+			}			
+			break;
+		}
 		case MYSQL_TYPE_DOUBLE: {
-			char *current_locale;
 			g_memmove (&doublevalue, mysql_bind_result[i].buffer, sizeof(double));
 			
-			current_locale = setlocale (LC_NUMERIC, "C");
-			if (type == G_TYPE_FLOAT)
-				g_value_set_float (value, (float) doublevalue);
-			else if (type == G_TYPE_DOUBLE)
+			if (type == G_TYPE_DOUBLE)
 				g_value_set_double (value, doublevalue);
 			else {
 				gda_row_invalidate_value (row, value);
@@ -750,8 +757,6 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, gint rownum, GError **error)
 					     _("Type %s not mapped for value %f"),
 					     g_type_name (type), doublevalue);
 			}
-			setlocale (LC_NUMERIC, current_locale);
-			
 			break;
 		}
 		case MYSQL_TYPE_STRING:
@@ -780,11 +785,15 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, gint rownum, GError **error)
 				gda_value_set_binary (value, &binary);
 			}
 			else if (type == GDA_TYPE_BLOB) {
-				GdaBinary binary = {
-					.data = (guchar*) strvalue,
-					.binary_length = length
+				/* web don't use GdaMysqlBlobOp because it looks like the MySQL
+				 * API does not support BLOBs accessed in a random way,
+				 * so we return the whole BLOB at once */
+				GdaBlob blob = {
+					.data.data = (guchar*) strvalue,
+					.data.binary_length = length,
+					.op = NULL
 				};
-				gda_value_set_binary (value, &binary);
+				gda_value_set_blob (value, &blob);
 			}
 			else if (type == G_TYPE_DOUBLE) {
 				if (length > 0) {
